function [d,w,c] = sdm(left, right, varargin)
%
%     Stereo matching on rectified images. Stratified dense matching
%     algorithm.
%
%     parameter description
%        input parameters
%
%            left, right  - rectified image pair 
%                           must be of double-float class
%
%           'SearchRange': disparity search range [min, max]
%                          default: [-image_width, image_width]
%
%	        'CsAlpha': factor defining confidence interval width (CIW) to
%	                   suppress correlation ambiguity due to noise
%                          default: 20 
%
%	         'CsBeta': value below which CIW must not fall, this is used
%                          to suppress structural ambiguity (erorrs due to
%                          repetitive structures)
%                          default: 0.05 
%
%        output parameters
%
%            d - disparity map
%            w - correlation map
%            c - classification into three classes: 
%                  4 internal error
%                  3 ambiguous (multiple matches possible)
%                  2 binocularly visible region
%                  1 half-occluded
%                  0 incomplete (single match or occluded)
%                NaN regions where matching is unable to give any answer
%                    (typically around image borders)
%
%		each pixel falls into one of the four categories.
%
%
%   EXAMPLE:
%       d = sdm(left, right, 'SearchRange', [dmin, dmax],...
%               'CsAlpha', 20, 'CsBeta', 0.05);
%
%   The algorithm is described in: 
%     J. Kostkova, R. Sara: Stratified Dense Matching for 
%     Stereopsis in Complex Scenes. In Proceedings 14th British
%     Machine Vision Conference (BMCV2003), pp. 339-348, British 
%     Machine Vision Association Press, September 2003 and is 
%     also available from:
%       http://cmp.felk.cvut.cz/~kostkj2/Publicat.html
%
%   Please refer to that article if you are publishing results 
%   based on this method.
% 
%
%
%  (c) Jana Kostkova (kostkova@cmp.felk.cvut.cz) 
%      FEE CTU Prague, 20 Aug 2004

error 'mex file not found'
return
