function [Di,Di_,fb] = sroc_dominant_intervals(rP1,rP2);
%
%  [Di,Di_,fb] = sroc_dominant_intervals(rP1,rP2);
%
%          computes dominant intervals for given two ROC curves
%
%  rP1, rP2 ... ROC curves [SR;ER] (of size 2xm1,2xm2)
%  Di ... Dominant inerval of rP1 over rP2 (sparsity interval)
%         (kx2), where k is number of pieces of a dominant set
%  Di_... Dominant interval on vertical axis (error interval)
%
% (c) Jan Cech, Jana Kostliva ({cechj, kostliva}@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

% compute SFB from rP1 and rP2
sr = [rP1(1,:), rP2(1,:)];
er = [rP1(2,:), rP2(2,:)];
alg_ind = [ones(1,size(rP1,2)),2*ones(1,size(rP2,2))];
fb = [];
while (~isempty(sr))
  ind = find(er == min(er));  
  ind1 = find(sr(ind) == min(sr(ind)));
  fb = [sr(ind(ind1))' er(ind(ind1))' alg_ind(ind(ind1))'; fb];
    
  ind2 = find((sr >= sr(ind(ind1(1)))) & ...
	      (er >= er(ind(ind1(1)))));
  sr(ind2) = [];
  er(ind2) = [];
  alg_ind(ind2) = [];
end			    

i = 1;
A = (fb(:,3)==i)';
if all(A),
    b = 1;
    e = length(A);
else
    bgning = hitmiss(A,[NaN,1,0]);
    ending = hitmiss(A,[0,1,NaN]);
    b = find(bgning);
    e = find(ending);
end

%shift interval
shift_e = zeros(size(e))';
for i=1:length(e),
    if e(i)==size(fb,1), %last
        shift_e(i) = 1-fb(e(i),2);
    else
        shift_e(i) = min(1-fb(e(i),2), fb(e(i)+1,1));
    end
end

Di = [fb(b,1), shift_e];

Di_ = zeros(size(Di));
for i=1:size(Di,1), %Dominant interval on vertical axis
    a = Di(i,1);
    %find nearest A;
    delta = (a-rP2(1,:));
    delta(delta<0) = inf;
    m = min(delta);
    k = find(delta == m);
    if isinf(m), 
       A = 1-a; %no better exist (take Z-point)
    else 
       A = rP2(2,k);
    end
    Di_(i,1) = A(1);
    
    b = Di(i,2);
    %find nearest B
    delta = (b-rP1(1,:));
    delta(delta<0) = inf;
    m = min(delta);
    k = find(delta == m);
    if isinf(m), 
       B = 1-b; %no better exist (take Z-point)
    else
       B = rP1(2,k);
    end
    Di_(i,2) = B(1);
end


