function E = sroc_efficiency(rP, interv);
%
%  E = ROC_efficiency(rP);
%
%         computes the efficiency of algorithm's ROC curve
%
%  Input: 
%      rP ... ROC boundary points (2xm) [SR;ER] 
%  interv ... (2x1) interval of SR where to compute (must be continuous);
%             optional, default: [0, 1]
% 
%
%  E... efficiency
%
% (c) Jan Cech, Jana Kostliva ({cechj, kostliva}@cmp.felk.cvut.cz)
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

rP = sortrows(rP');    

if exist('interv','var')
    b = interv(1);
    e = interv(2);
    i = find(rP(:,1)<b); rP(i,:) = [];
    i = find(rP(:,1)>e); rP(i,:) = [];
end

if isempty(rP), 
    E = 0;
    return
end
    
e = rP(:,2); e(end+1,:) = e(end);
s = rP(:,1); s(end+1,:) = 1-e(end);

%add points lying on the Z-curve
s_ = (1-e);
t = find([s;NaN]>[NaN;s_])-1;

if isempty(t),
    ss = s;
    ee = e;
else
    ss = [s;1-e(t);s(t+1)];
    ee = [e;e(t);1-s(t+1)];
end

p = [ss,ee];
p = sortrows(p);
s = p(:,1); e = p(:,2);

E = 0;
for i=2:length(s);
    a = s(i)-s(i-1);
    b = 1-s(i-1) - e(i-1);
    c = s(i)-s(i-1); %1-s(i-1) - (1-s(i)); %
    E = E + max(0,a*(b-0.5*c));
end
E = 2*E;




