%
% sroc_init_example
%   example script how to initialize sroc parameters
%
% Used method, Stratified dense matching, is described in: 
%    J. Kostkova, R. Sara: Stratified Dense Matching for 
%    Stereopsis in Complex Scenes. In Proceedings 14th British
%    Machine Vision Conference (BMCV2003), pp. 339-348, British 
%    Machine Vision Association Press, September 2003 and is 
%    also available from:
%      http://cmp.felk.cvut.cz/~kostkj2/Publicat.html
%
%  Please refer to that article if you are publishing results 
%  based on this method.
% 
%
% (c) Jana Kostliva (kostliva@cmp.felk.cvut.cz) 
%     CMP, FEE CTU in Prague, 23-Apr-2007
%

sroc = [];

% fill the algorithm name, authors, algorithm abbreviation (to be 
%    used in plots and tables) and bib-reference (to easily identify 
%    the algorithm)
% necesarry when uploaded only

sroc.alg_name = 'Stratified Dense Matching';
sroc.alg_authors = 'J. Kostkova, R. Sara';
sroc.alg_abbrv = 'SDM-test';
sroc.alg_bibref = 'J.Kostkova, R. Sara: Stratified Dense Matching for Stereopsis in Complex Scenes, In BMVC2003, pp.339-348, 2003.';

% fill the parameter name (cell list) and values (array) under
%    which the algroithm will be evaluated
% REQUIRED

sroc.param_name = {'alpha', 'beta'};

a = 0:10:20;
b = 0:0.02:0.05;
%a = 10;
%b = [0,0.02];
[aa,bb] = meshgrid(a, b);
A = reshape(aa,1,prod(size(aa)));
B = reshape(bb,1,prod(size(bb)));
sroc.params = [A;B];

% list of scenes for evaluation

sroc.scenes = {'cones','slits','stripes','teddy','tsukuba', ...
	       'venus'};

% paths setting

sroc.rootPth = '.';
sroc.ImgPth = [sroc.rootPth '/Images'];
sroc.ResPth = [sroc.rootPth '/Results/' sroc.alg_abbrv];

% Do you want to export the results to files (plots to eps, pdf 
% and fig; improvements and efficiency to tex)?
% 0 ... no export, 1 ... export

sroc.export_results = 1;

% Do you want to prepare the results for upload?
% 0 ... no upload, 1 ... prepare upload

sroc.upload = 0; 


addpath([sroc.rootPth '/Code']);
